pub struct ExportCommand {Show 15 fields
addr: String,
output_dir: Option<String>,
database: String,
db_parallelism: usize,
table_parallelism: usize,
max_retry: usize,
target: ExportTarget,
start_time: Option<String>,
end_time: Option<String>,
auth_basic: Option<String>,
timeout: Option<Duration>,
proxy: Option<String>,
no_proxy: bool,
ddl_local_dir: Option<String>,
storage: ObjectStoreConfig,
}Expand description
Command for exporting data from the GreptimeDB.
Fields
addr: StringServer address to connect
output_dir: Option<String>Directory to put the exported data. E.g.: /tmp/greptimedb-export for local export.
database: StringThe name of the catalog to export.
db_parallelism: usizeThe number of databases exported in parallel.
For example, if there are 20 databases and db_parallelism is 4,
4 databases will be exported concurrently.
table_parallelism: usizeThe number of tables exported in parallel within a single database.
For example, if a database has 30 tables and parallelism is 8,
8 tables will be exported concurrently.
max_retry: usizeMax retry times for each job.
target: ExportTargetThings to export
start_time: Option<String>A half-open time range: [start_time, end_time). The start of the time range (time-index column) for data export.
end_time: Option<String>A half-open time range: [start_time, end_time). The end of the time range (time-index column) for data export.
auth_basic: Option<String>The basic authentication for connecting to the server
timeout: Option<Duration>The timeout of invoking the database.
It is used to override the server-side timeout setting.
The default behavior will disable server-side default timeout(i.e. 0s).
proxy: Option<String>The proxy server address to connect.
If set, it overrides the system proxy unless --no-proxy is specified.
If neither --proxy nor --no-proxy is set, system proxy (env) may be used.
no_proxy: boolDisable all proxy usage (ignores --proxy and system proxy).
When set and --proxy is not provided, this explicitly disables system proxy.
ddl_local_dir: Option<String>if both ddl_local_dir and remote storage are set, ddl_local_dir will be only used for
exported SQL files, and the data will be exported to remote storage.
Note that ddl_local_dir export sql files to LOCAL file system, this is useful if export client don’t have
direct access to remote storage.
if remote storage is set but ddl_local_dir is not set, both SQL&data will be exported to remote storage.
storage: ObjectStoreConfigImplementations